__doc__ = """
Python wrapper for Loyverse API

Copyright: (c) 2020, Matteo Berchier
"""

__title__ = "loyverse"
__version__ = "0.0.1"
__author__ = "Matteo Berchier <maberchier@gmail.com>"
__copyright__ = "(c) 2020, Matteo Berchier"

from loyverse.client import Client

__all__ = ('Client',)
